@@ -267,13 +267,11 @@ class App(object):
             *cfg_module - модуль конфигурации
         '''
         self.cfg_module = cfg_module
-
-
-    def __call__(self, environ, start_response):
+    
+    def setup(self, environ, start_response):
         '''
         Первый запуск
         '''
-        setattr(self.__class__, '__call__', self._call)
         def routing_queue(routing):
             list_obj_from_str(routing)
             def wrapper(rq):
@@ -307,12 +305,12 @@ class App(object):
         self.routing = obj_from_str(cfg.ROUTING)
         if isinstance(self.routing, (tuple, list)):
             self.routing = routing_queue(self.routing)
-            
-        return self._call(environ, start_response)
 
-    def _call(self, environ, start_response):
-        rq = Request(environ)
+    def __call__(self, environ, start_response):
         try:
+            if not hasattr(self, 'request_middlewares'):
+                self.setup(environ, start_response)
+            rq = Request(environ)
             for middleware in self.request_middlewares:
                 middleware(rq)
             res = self.routing(rq)
@@ -330,8 +328,9 @@ class App(object):
                     code=404, content_type='text/plain')
             else:
                 res = cfg.ERROR_PAGES[404](rq)
-        except:
-            tb = make_traceback(rq.host)
+        except Exception:
+            tb = make_traceback(environ.get('HTTP_X_FORWARDED_HOST',
+                environ.get('HTTP_HOST', environ.get('SERVER_NAME'))))
             logging.error(tb)
             if cfg.DEBUG:
                 res = Response(tb, code=500, content_type='text/plain')
